jsonschema

package
v0.5.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 20, 2026 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

const JSONSchemaTypeArray = JSONSchemaType('[')
const JSONSchemaTypeObject = JSONSchemaType('{')
const JSONSchemaTypeUnknown = JSONSchemaType(0)

Variables

This section is empty.

Functions

This section is empty.

Types

type JSONSchemaAble

type JSONSchemaAble interface {
	// JSONSchemaType returns a type that distinguishes between arrays and objects, after Next returned an EnterHint.
	JSONSchemaType() JSONSchemaType
}

JSONSchemaAble is an extra method for a Parser that distinguishes between objects and arrays. This allows the Parser to tagged to handle JSONSchema `{"type": "object"}` and `{"type":"array"}`. Tagging is actually added using the `tag` package, this interface only makes tagging possible.

type JSONSchemaType

type JSONSchemaType byte

Jump to