Documentation
¶
Index ¶
Constants ¶
const JSONSchemaTypeArray = JSONSchemaType('[')
const JSONSchemaTypeObject = JSONSchemaType('{')
const JSONSchemaTypeUnknown = JSONSchemaType(0)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type JSONSchemaAble ¶
type JSONSchemaAble interface {
// JSONSchemaType returns a type that distinguishes between arrays and objects, after Next returned an EnterHint.
JSONSchemaType() JSONSchemaType
}
JSONSchemaAble is an extra method for a Parser that distinguishes between objects and arrays. This allows the Parser to tagged to handle JSONSchema `{"type": "object"}` and `{"type":"array"}`. Tagging is actually added using the `tag` package, this interface only makes tagging possible.
type JSONSchemaType ¶
type JSONSchemaType byte
Click to show internal directories.
Click to hide internal directories.